#[non_exhaustive]pub struct RegistryHostConfig {
pub server: String,
pub hosts: Vec<HostConfig>,
/* private fields */
}Expand description
RegistryHostConfig configures the top-level structure for a single containerd registry server’s configuration, which represents one hosts.toml file on the node. It will override the same fqdns in PrivateRegistryAccessConfig.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.server: StringDefines the host name of the registry server, which will be used to create configuration file as /etc/containerd/hosts.d/<server>/hosts.toml. It supports fully qualified domain names (FQDN) and IP addresses: Specifying port is supported, while scheme and path are NOT supported. Wildcards are NOT supported. Examples:
my.customdomain.com10.0.1.2:5000
hosts: Vec<HostConfig>HostConfig configures a list of host-specific configurations for the server. Each server can have at most 10 host configurations.
Implementations
Sourceimpl RegistryHostConfig
impl RegistryHostConfig