#[non_exhaustive]pub enum CurrentState {
Unspecified,
Encrypted,
Decrypted,
EncryptionPending,
EncryptionError,
DecryptionPending,
DecryptionError,
AllObjectsEncryptionEnabled,
AllObjectsEncryptionPending,
AllObjectsEncryptionError,
UnknownValue(UnknownValue),
}Expand description
Current State of etcd encryption.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Should never be set
Encrypted
Secrets in etcd are encrypted.
Decrypted
Secrets in etcd are stored in plain text (at etcd level) - this is unrelated to Compute Engine level full disk encryption.
EncryptionPending
Encryption (or re-encryption with a different CloudKMS key) of Secrets is in progress.
EncryptionError
Encryption (or re-encryption with a different CloudKMS key) of Secrets in etcd encountered an error.
DecryptionPending
De-crypting Secrets to plain text in etcd is in progress.
DecryptionError
De-crypting Secrets to plain text in etcd encountered an error.
AllObjectsEncryptionEnabled
Encryption of all objects in the storage is enabled. It does not guarantee that all objects in the storage are encrypted, but eventually they will be.
AllObjectsEncryptionPending
Enablement of the encryption of all objects in storage is pending.
AllObjectsEncryptionError
Enabling encryption of all objects in storage encountered an error.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using CurrentState::value or CurrentState::name.
Implementations