#[non_exhaustive]pub enum NodePoolUpdateStrategy {
Unspecified,
BlueGreen,
Surge,
ShortLived,
UnknownValue(UnknownValue),
}Expand description
Strategy used for node pool update.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value if unset. GKE internally defaults the update strategy to SURGE for unspecified strategies.
BlueGreen
blue-green upgrade.
Surge
SURGE is the traditional way of upgrade a node pool. max_surge and max_unavailable determines the level of upgrade parallelism.
ShortLived
SHORT_LIVED is the dedicated upgrade strategy for QueuedProvisioning and flex start node pools scaled up only by enqueueing to the Dynamic Workload Scheduler (DWS).
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using NodePoolUpdateStrategy::value or NodePoolUpdateStrategy::name.
Implementations