Module linux_node_config

Module linux_node_config 

Defines additional types related to LinuxNodeConfig.

Modules

custom_node_init
Defines additional types related to CustomNodeInit.
node_kernel_module_loading
Defines additional types related to NodeKernelModuleLoading.
swap_config
Defines additional types related to SwapConfig.

Structs

AccurateTimeConfig
AccurateTimeConfig contains configuration for the accurate time synchronization feature.
CustomNodeInit
Support for running custom init code while bootstrapping nodes.
HugepagesConfig
Hugepages amount in both 2m and 1g size
NodeKernelModuleLoading
Configuration for kernel module loading on nodes.
SwapConfig
Configuration for swap memory on a node pool.

Enums

CgroupMode
Possible cgroup modes that can be used.
TransparentHugepageDefrag
Possible values for transparent hugepage defrag support.
TransparentHugepageEnabled
Possible values for transparent hugepage enabled support.