#[non_exhaustive]pub enum TransparentHugepageEnabled {
Unspecified,
Always,
Madvise,
Never,
UnknownValue(UnknownValue),
}Expand description
Possible values for transparent hugepage enabled support.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value. GKE will not modify the kernel configuration.
Always
Transparent hugepage support for anonymous memory is enabled system wide.
Madvise
Transparent hugepage support for anonymous memory is enabled inside MADV_HUGEPAGE regions. This is the default kernel configuration.
Never
Transparent hugepage support for anonymous memory is disabled.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using TransparentHugepageEnabled::value or TransparentHugepageEnabled::name.
Implementations