#[non_exhaustive]pub struct AccurateTimeConfig {
pub enable_ptp_kvm_time_sync: Option<bool>,
/* private fields */
}Expand description
AccurateTimeConfig contains configuration for the accurate time synchronization feature.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enable_ptp_kvm_time_sync: Option<bool>Enables enhanced time synchronization using PTP-KVM.
Implementations
Sourceimpl AccurateTimeConfig
impl AccurateTimeConfig
Sourcepub fn set_enable_ptp_kvm_time_sync<T>(self, v: T) -> Self
pub fn set_enable_ptp_kvm_time_sync<T>(self, v: T) -> Self
Sets the value of enable_ptp_kvm_time_sync.
Example
ⓘ
let x = AccurateTimeConfig::new().set_enable_ptp_kvm_time_sync(true);Sourcepub fn set_or_clear_enable_ptp_kvm_time_sync<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_enable_ptp_kvm_time_sync<T>(self, v: Option<T>) -> Self
Sets or clears the value of enable_ptp_kvm_time_sync.
Example
ⓘ
let x = AccurateTimeConfig::new().set_or_clear_enable_ptp_kvm_time_sync(Some(false));
let x = AccurateTimeConfig::new().set_or_clear_enable_ptp_kvm_time_sync(None::<bool>);Trait Implementations
Sourceimpl Clone for AccurateTimeConfig
impl Clone for AccurateTimeConfig
Sourcefn clone(&self) -> AccurateTimeConfig
fn clone(&self) -> AccurateTimeConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccurateTimeConfig
impl Debug for AccurateTimeConfig
Sourceimpl Default for AccurateTimeConfig
impl Default for AccurateTimeConfig
Sourcefn default() -> AccurateTimeConfig
fn default() -> AccurateTimeConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for AccurateTimeConfig
impl Message for AccurateTimeConfig
Sourceimpl PartialEq for AccurateTimeConfig
impl PartialEq for AccurateTimeConfig
Sourcefn eq(&self, other: &AccurateTimeConfig) -> bool
fn eq(&self, other: &AccurateTimeConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AccurateTimeConfig