#[non_exhaustive]pub struct CustomNodeInit {
pub init_script: Option<InitScript>,
/* private fields */
}Expand description
Support for running custom init code while bootstrapping nodes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.init_script: Option<InitScript>Optional. The init script to be executed on the node.
Implementations
Sourceimpl CustomNodeInit
impl CustomNodeInit
Sourcepub fn set_init_script<T>(self, v: T) -> Selfwhere
T: Into<InitScript>,
pub fn set_init_script<T>(self, v: T) -> Selfwhere
T: Into<InitScript>,
Sets the value of init_script.
Example
ⓘ
use google_cloud_container_v1::model::linux_node_config::custom_node_init::InitScript;
let x = CustomNodeInit::new().set_init_script(InitScript::default()/* use setters */);Sourcepub fn set_or_clear_init_script<T>(self, v: Option<T>) -> Selfwhere
T: Into<InitScript>,
pub fn set_or_clear_init_script<T>(self, v: Option<T>) -> Selfwhere
T: Into<InitScript>,
Sets or clears the value of init_script.
Example
ⓘ
use google_cloud_container_v1::model::linux_node_config::custom_node_init::InitScript;
let x = CustomNodeInit::new().set_or_clear_init_script(Some(InitScript::default()/* use setters */));
let x = CustomNodeInit::new().set_or_clear_init_script(None::<InitScript>);Trait Implementations
Sourceimpl Clone for CustomNodeInit
impl Clone for CustomNodeInit
Sourcefn clone(&self) -> CustomNodeInit
fn clone(&self) -> CustomNodeInit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CustomNodeInit
impl Debug for CustomNodeInit
Sourceimpl Default for CustomNodeInit
impl Default for CustomNodeInit
Sourcefn default() -> CustomNodeInit
fn default() -> CustomNodeInit
Returns the “default value” for a type. Read more
Sourceimpl Message for CustomNodeInit
impl Message for CustomNodeInit
Sourceimpl PartialEq for CustomNodeInit
impl PartialEq for CustomNodeInit
Sourcefn eq(&self, other: &CustomNodeInit) -> bool
fn eq(&self, other: &CustomNodeInit) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CustomNodeInit