Policy

#[non_exhaustive]
pub enum Policy { DailyMaintenanceWindow(Box<DailyMaintenanceWindow>), RecurringWindow(Box<RecurringTimeWindow>), RecurringMaintenanceWindow(Box<RecurringMaintenanceWindow>), }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DailyMaintenanceWindow(Box<DailyMaintenanceWindow>)

DailyMaintenanceWindow specifies a daily maintenance operation window.



RecurringWindow(Box<RecurringTimeWindow>)

RecurringWindow specifies some number of recurring time periods for maintenance to occur. The time windows may be overlapping. If no maintenance windows are set, maintenance can occur at any time.



RecurringMaintenanceWindow(Box<RecurringMaintenanceWindow>)

RecurringMaintenanceWindow specifies some number of recurring time periods for maintenance to occur. The time windows may be overlapping. If no maintenance windows are set, maintenance can occur at any time. Alternative to RecurringWindow, with renamed fields.