#[non_exhaustive]pub enum EffectiveCgroupMode {
Unspecified,
V1,
V2,
UnknownValue(UnknownValue),
}Expand description
Possible effective cgroup modes for the node.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
EFFECTIVE_CGROUP_MODE_UNSPECIFIED means the cgroup configuration for the node pool is unspecified, i.e. the node pool is a Windows node pool.
V1
CGROUP_MODE_V1 means the node pool is configured to use cgroupv1 for the cgroup configuration.
V2
CGROUP_MODE_V2 means the node pool is configured to use cgroupv2 for the cgroup configuration.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using EffectiveCgroupMode::value or EffectiveCgroupMode::name.
Implementations