#[non_exhaustive]pub struct CrashLoopBackOffConfig {
pub max_container_restart_period: String,
/* private fields */
}Expand description
Contains config to modify node-level parameters for container restart behavior.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_container_restart_period: StringOptional. The maximum duration the backoff delay can accrue to for container restarts, minimum 1 second, maximum 300 seconds. If not set, defaults to the internal crashloopbackoff maximum.
The string must be a sequence of decimal numbers, each with optional fraction and a unit suffix, such as “300ms”. Valid time units are “ns”, “us” (or “µs”), “ms”, “s”, “m”, “h”.
See https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#configurable-container-restart-delay for more details.
Implementations
Sourceimpl CrashLoopBackOffConfig
impl CrashLoopBackOffConfig
Sourcepub fn set_max_container_restart_period<T: Into<String>>(self, v: T) -> Self
pub fn set_max_container_restart_period<T: Into<String>>(self, v: T) -> Self
Sets the value of max_container_restart_period.
Example
ⓘ
let x = CrashLoopBackOffConfig::new().set_max_container_restart_period("example");Trait Implementations
Sourceimpl Clone for CrashLoopBackOffConfig
impl Clone for CrashLoopBackOffConfig
Sourcefn clone(&self) -> CrashLoopBackOffConfig
fn clone(&self) -> CrashLoopBackOffConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CrashLoopBackOffConfig
impl Debug for CrashLoopBackOffConfig
Sourceimpl Default for CrashLoopBackOffConfig
impl Default for CrashLoopBackOffConfig
Sourcefn default() -> CrashLoopBackOffConfig
fn default() -> CrashLoopBackOffConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for CrashLoopBackOffConfig
impl Message for CrashLoopBackOffConfig
Sourceimpl PartialEq for CrashLoopBackOffConfig
impl PartialEq for CrashLoopBackOffConfig
Sourcefn eq(&self, other: &CrashLoopBackOffConfig) -> bool
fn eq(&self, other: &CrashLoopBackOffConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CrashLoopBackOffConfig