This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The RUNNING_WITH_ERROR state indicates the node pool has been created
and is partially usable. Some error state has occurred and some
functionality may be impaired. Customer may need to reissue a request
or trigger a new update.
The RECONCILING state indicates that some work is actively being done on
the node pool, such as upgrading node software. Details can
be found in the statusMessage field.