#[non_exhaustive]pub struct ExclusionUntilEndOfSupport {
pub enabled: bool,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
/* private fields */
}Expand description
Defines the maintenance exclusion for the node pool.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolOptional. Indicates whether the exclusion is enabled.
start_time: Option<Timestamp>Output only. The start time of the maintenance exclusion. It is output only. It is the exclusion creation time.
end_time: Option<Timestamp>Output only. The end time of the maintenance exclusion. It is output only. It is the cluster control plane version’s end of support time, or end of extended support time when the cluster is on extended support channel.
Implementations
Sourceimpl ExclusionUntilEndOfSupport
impl ExclusionUntilEndOfSupport
Sourcepub fn set_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_enabled<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
ⓘ
use wkt::Timestamp;
let x = ExclusionUntilEndOfSupport::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
ⓘ
use wkt::Timestamp;
let x = ExclusionUntilEndOfSupport::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = ExclusionUntilEndOfSupport::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self