#[non_exhaustive]pub struct NodePoolMaintenancePolicy {
pub exclusion_until_end_of_support: Option<ExclusionUntilEndOfSupport>,
/* private fields */
}Expand description
Defines the maintenance policy for the node pool.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.exclusion_until_end_of_support: Option<ExclusionUntilEndOfSupport>Optional. The exclusion until end of support for the node pool.
Implementations
Sourceimpl NodePoolMaintenancePolicy
impl NodePoolMaintenancePolicy
Sourcepub fn set_exclusion_until_end_of_support<T>(self, v: T) -> Selfwhere
T: Into<ExclusionUntilEndOfSupport>,
pub fn set_exclusion_until_end_of_support<T>(self, v: T) -> Selfwhere
T: Into<ExclusionUntilEndOfSupport>,
Sets the value of exclusion_until_end_of_support.
Example
ⓘ
use google_cloud_container_v1::model::node_pool::ExclusionUntilEndOfSupport;
let x = NodePoolMaintenancePolicy::new().set_exclusion_until_end_of_support(ExclusionUntilEndOfSupport::default()/* use setters */);Sourcepub fn set_or_clear_exclusion_until_end_of_support<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<ExclusionUntilEndOfSupport>,
pub fn set_or_clear_exclusion_until_end_of_support<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<ExclusionUntilEndOfSupport>,
Sets or clears the value of exclusion_until_end_of_support.
Example
ⓘ
use google_cloud_container_v1::model::node_pool::ExclusionUntilEndOfSupport;
let x = NodePoolMaintenancePolicy::new().set_or_clear_exclusion_until_end_of_support(Some(ExclusionUntilEndOfSupport::default()/* use setters */));
let x = NodePoolMaintenancePolicy::new().set_or_clear_exclusion_until_end_of_support(None::<ExclusionUntilEndOfSupport>);Trait Implementations
Sourceimpl Clone for NodePoolMaintenancePolicy
impl Clone for NodePoolMaintenancePolicy
Sourcefn clone(&self) -> NodePoolMaintenancePolicy
fn clone(&self) -> NodePoolMaintenancePolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NodePoolMaintenancePolicy
impl Debug for NodePoolMaintenancePolicy
Sourceimpl Default for NodePoolMaintenancePolicy
impl Default for NodePoolMaintenancePolicy
Sourcefn default() -> NodePoolMaintenancePolicy
fn default() -> NodePoolMaintenancePolicy
Returns the “default value” for a type. Read more
Sourceimpl Message for NodePoolMaintenancePolicy
impl Message for NodePoolMaintenancePolicy
Sourceimpl PartialEq for NodePoolMaintenancePolicy
impl PartialEq for NodePoolMaintenancePolicy
Sourcefn eq(&self, other: &NodePoolMaintenancePolicy) -> bool
fn eq(&self, other: &NodePoolMaintenancePolicy) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NodePoolMaintenancePolicy