QueuedProvisioning

Struct QueuedProvisioning 

#[non_exhaustive]
pub struct QueuedProvisioning { pub enabled: bool, /* private fields */ }
QueuedProvisioning defines the queued provisioning used by the node pool.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
enabled: bool

Denotes that this node pool is QRM specific, meaning nodes can be only obtained through queuing via the Cluster Autoscaler ProvisioningRequest API.

Implementations

Source

impl QueuedProvisioning

pub fn new() -> Self

Creates a new default instance.

pub fn set_enabled<T: Into<bool>>(self, v: T) -> Self

Sets the value of enabled.

Example
let x = QueuedProvisioning::new().set_enabled(true);