#[non_exhaustive]pub enum Code {
Unknown,
GceStockout,
GkeServiceAccountDeleted,
GceQuotaExceeded,
SetByOperator,
CloudKmsKeyError,
CaExpiring,
NodeServiceAccountMissingPermissions,
CloudKmsKeyDestroyed,
UnknownValue(UnknownValue),
}Expand description
Code for each condition
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unknown
UNKNOWN indicates a generic condition.
GceStockout
GCE_STOCKOUT indicates that Google Compute Engine resources are temporarily unavailable.
GkeServiceAccountDeleted
GKE_SERVICE_ACCOUNT_DELETED indicates that the user deleted their robot service account.
GceQuotaExceeded
Google Compute Engine quota was exceeded.
SetByOperator
Cluster state was manually changed by an SRE due to a system logic error.
CloudKmsKeyError
Unable to perform an encrypt operation against the CloudKMS key used for etcd level encryption.
CaExpiring
Cluster CA is expiring soon.
NodeServiceAccountMissingPermissions
Node service account is missing permissions.
CloudKmsKeyDestroyed
Cloud KMS key version used for etcd level encryption has been destroyed. This is a permanent error.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Code::value or Code::name.