#[non_exhaustive]pub struct CustomImageConfig {
pub image: String,
pub image_project: String,
/* private fields */
}Expand description
CustomImageConfig contains the information r
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.image: StringThe name of the image to use for this node.
image_project: StringThe project containing the image to use for this node.
Implementations
Sourceimpl CustomImageConfig
impl CustomImageConfig