#[non_exhaustive]pub struct DisruptionBudget {
pub minor_version_disruption_interval: Option<Duration>,
pub patch_version_disruption_interval: Option<Duration>,
pub last_minor_version_disruption_time: Option<Timestamp>,
pub last_disruption_time: Option<Timestamp>,
/* private fields */
}Expand description
DisruptionBudget defines the upgrade disruption budget for the cluster control plane.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.minor_version_disruption_interval: Option<Duration>Optional. The minimum duration between two minor version upgrades of the control plane.
patch_version_disruption_interval: Option<Duration>Optional. The minimum duration between two patch version upgrades of the control plane.
last_minor_version_disruption_time: Option<Timestamp>Output only. The last time a minor version upgrade was performed on the control plane.
last_disruption_time: Option<Timestamp>Output only. The last time a disruption was performed on the control plane.
Implementations
Sourceimpl DisruptionBudget
impl DisruptionBudget
Sourcepub fn set_minor_version_disruption_interval<T>(self, v: T) -> Self
pub fn set_minor_version_disruption_interval<T>(self, v: T) -> Self
Sets the value of minor_version_disruption_interval.
Example
use wkt::Duration;
let x = DisruptionBudget::new().set_minor_version_disruption_interval(Duration::default()/* use setters */);Sourcepub fn set_or_clear_minor_version_disruption_interval<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_minor_version_disruption_interval<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of minor_version_disruption_interval.
Example
use wkt::Duration;
let x = DisruptionBudget::new().set_or_clear_minor_version_disruption_interval(Some(Duration::default()/* use setters */));
let x = DisruptionBudget::new().set_or_clear_minor_version_disruption_interval(None::<Duration>);Sourcepub fn set_patch_version_disruption_interval<T>(self, v: T) -> Self
pub fn set_patch_version_disruption_interval<T>(self, v: T) -> Self
Sets the value of patch_version_disruption_interval.
Example
use wkt::Duration;
let x = DisruptionBudget::new().set_patch_version_disruption_interval(Duration::default()/* use setters */);Sourcepub fn set_or_clear_patch_version_disruption_interval<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_patch_version_disruption_interval<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of patch_version_disruption_interval.
Example
use wkt::Duration;
let x = DisruptionBudget::new().set_or_clear_patch_version_disruption_interval(Some(Duration::default()/* use setters */));
let x = DisruptionBudget::new().set_or_clear_patch_version_disruption_interval(None::<Duration>);Sourcepub fn set_last_minor_version_disruption_time<T>(self, v: T) -> Self
pub fn set_last_minor_version_disruption_time<T>(self, v: T) -> Self
Sets the value of last_minor_version_disruption_time.
Example
use wkt::Timestamp;
let x = DisruptionBudget::new().set_last_minor_version_disruption_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_last_minor_version_disruption_time<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_last_minor_version_disruption_time<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of last_minor_version_disruption_time.
Example
use wkt::Timestamp;
let x = DisruptionBudget::new().set_or_clear_last_minor_version_disruption_time(Some(Timestamp::default()/* use setters */));
let x = DisruptionBudget::new().set_or_clear_last_minor_version_disruption_time(None::<Timestamp>);Sourcepub fn set_last_disruption_time<T>(self, v: T) -> Self
pub fn set_last_disruption_time<T>(self, v: T) -> Self
Sets the value of last_disruption_time.
Example
use wkt::Timestamp;
let x = DisruptionBudget::new().set_last_disruption_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_last_disruption_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_disruption_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_disruption_time.
Example
use wkt::Timestamp;
let x = DisruptionBudget::new().set_or_clear_last_disruption_time(Some(Timestamp::default()/* use setters */));
let x = DisruptionBudget::new().set_or_clear_last_disruption_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for DisruptionBudget
impl Clone for DisruptionBudget
Sourcefn clone(&self) -> DisruptionBudget
fn clone(&self) -> DisruptionBudget
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DisruptionBudget
impl Debug for DisruptionBudget
Sourceimpl Default for DisruptionBudget
impl Default for DisruptionBudget
Sourcefn default() -> DisruptionBudget
fn default() -> DisruptionBudget
Sourceimpl Message for DisruptionBudget
impl Message for DisruptionBudget
Sourceimpl PartialEq for DisruptionBudget
impl PartialEq for DisruptionBudget
Sourcefn eq(&self, other: &DisruptionBudget) -> bool
fn eq(&self, other: &DisruptionBudget) -> bool
self and other values to be equal, and is used by ==.