#[non_exhaustive]pub struct LustreCsiDriverConfig {
pub enabled: bool,
pub enable_legacy_lustre_port: bool,
pub disable_multi_nic: bool,
/* private fields */
}Expand description
Configuration for the Lustre CSI driver.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolWhether the Lustre CSI driver is enabled for this cluster.
enable_legacy_lustre_port: bool👎Deprecated
If set to true, the Lustre CSI driver will install Lustre kernel modules using port 6988. This serves as a workaround for a port conflict with the gke-metadata-server. This field is required ONLY under the following conditions:
- The GKE node version is older than 1.33.2-gke.4655000.
- You’re connecting to a Lustre instance that has the
‘gke-support-enabled’ flag.
Deprecated: This flag is no longer required as of GKE node version
1.33.2-gke.4655000, unless you are connecting to a Lustre instance
that has the
gke-support-enabledflag.
disable_multi_nic: boolWhen set to true, this disables multi-NIC support for the Lustre CSI driver. By default, GKE enables multi-NIC support, which allows the Lustre CSI driver to automatically detect and configure all suitable network interfaces on a node to maximize I/O performance for demanding workloads.
Implementations
Sourceimpl LustreCsiDriverConfig
impl LustreCsiDriverConfig
Sourcepub fn set_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_enabled<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_enable_legacy_lustre_port<T: Into<bool>>(self, v: T) -> Self
👎Deprecated
pub fn set_enable_legacy_lustre_port<T: Into<bool>>(self, v: T) -> Self
Sets the value of enable_legacy_lustre_port.
Example
ⓘ
let x = LustreCsiDriverConfig::new().set_enable_legacy_lustre_port(true);Sourcepub fn set_disable_multi_nic<T: Into<bool>>(self, v: T) -> Self
pub fn set_disable_multi_nic<T: Into<bool>>(self, v: T) -> Self
Sets the value of disable_multi_nic.
Example
ⓘ
let x = LustreCsiDriverConfig::new().set_disable_multi_nic(true);Trait Implementations
Sourceimpl Clone for LustreCsiDriverConfig
impl Clone for LustreCsiDriverConfig
Sourcefn clone(&self) -> LustreCsiDriverConfig
fn clone(&self) -> LustreCsiDriverConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LustreCsiDriverConfig
impl Debug for LustreCsiDriverConfig
Sourceimpl Default for LustreCsiDriverConfig
impl Default for LustreCsiDriverConfig
Sourcefn default() -> LustreCsiDriverConfig
fn default() -> LustreCsiDriverConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for LustreCsiDriverConfig
impl Message for LustreCsiDriverConfig
Sourceimpl PartialEq for LustreCsiDriverConfig
impl PartialEq for LustreCsiDriverConfig
Sourcefn eq(&self, other: &LustreCsiDriverConfig) -> bool
fn eq(&self, other: &LustreCsiDriverConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LustreCsiDriverConfig