NodeNetworkConfig

Struct NodeNetworkConfig 

#[non_exhaustive]
pub struct NodeNetworkConfig { pub create_pod_range: bool, pub pod_range: String, pub pod_ipv4_cidr_block: String, pub enable_private_nodes: Option<bool>, pub network_performance_config: Option<NetworkPerformanceConfig>, pub pod_cidr_overprovision_config: Option<PodCIDROverprovisionConfig>, pub additional_node_network_configs: Vec<AdditionalNodeNetworkConfig>, pub additional_pod_network_configs: Vec<AdditionalPodNetworkConfig>, pub pod_ipv4_range_utilization: f64, pub subnetwork: String, pub network_tier_config: Option<NetworkTierConfig>, pub accelerator_network_profile: String, /* private fields */ }
Parameters for node pool-level network config.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
create_pod_range: bool

Input only. Whether to create a new range for pod IPs in this node pool. Defaults are provided for pod_range and pod_ipv4_cidr_block if they are not specified.

If neither create_pod_range or pod_range are specified, the cluster-level default (ip_allocation_policy.cluster_ipv4_cidr_block) is used.

Only applicable if ip_allocation_policy.use_ip_aliases is true.

This field cannot be changed after the node pool has been created.

pod_range: String

The ID of the secondary range for pod IPs. If create_pod_range is true, this ID is used for the new range. If create_pod_range is false, uses an existing secondary range with this ID.

Only applicable if ip_allocation_policy.use_ip_aliases is true.

This field cannot be changed after the node pool has been created.

pod_ipv4_cidr_block: String

The IP address range for pod IPs in this node pool.

Only applicable if create_pod_range is true.

Set to blank to have a range chosen with the default size.

Set to /netmask (e.g. /14) to have a range chosen with a specific netmask.

Set to a CIDR notation (e.g. 10.96.0.0/14) to pick a specific range to use.

Only applicable if ip_allocation_policy.use_ip_aliases is true.

This field cannot be changed after the node pool has been created.

enable_private_nodes: Option<bool>

Whether nodes have internal IP addresses only. If enable_private_nodes is not specified, then the value is derived from [Cluster.NetworkConfig.default_enable_private_nodes][]

network_performance_config: Option<NetworkPerformanceConfig>

Network bandwidth tier configuration.

pod_cidr_overprovision_config: Option<PodCIDROverprovisionConfig>

[PRIVATE FIELD] Pod CIDR size overprovisioning config for the node pool.

Pod CIDR size per node depends on max_pods_per_node. By default, the value of max_pods_per_node is rounded off to next power of 2 and we then double that to get the size of pod CIDR block per node. Example: max_pods_per_node of 30 would result in 64 IPs (/26).

This config can disable the doubling of IPs (we still round off to next power of 2) Example: max_pods_per_node of 30 will result in 32 IPs (/27) when overprovisioning is disabled.

additional_node_network_configs: Vec<AdditionalNodeNetworkConfig>

We specify the additional node networks for this node pool using this list. Each node network corresponds to an additional interface

additional_pod_network_configs: Vec<AdditionalPodNetworkConfig>

We specify the additional pod networks for this node pool using this list. Each pod network corresponds to an additional alias IP range for the node

pod_ipv4_range_utilization: f64

Output only. The utilization of the IPv4 range for the pod. The ratio is Usage/[Total number of IPs in the secondary range], Usage=numNodesnumZonespodIPsPerNode.

subnetwork: String

Optional. The subnetwork name/path for the node pool. Format: projects/{project}/regions/{region}/subnetworks/{subnetwork} If the cluster is associated with multiple subnetworks, the subnetwork can be either:

  • A user supplied subnetwork name during node pool creation (e.g., my-subnet). The name must be between 1 and 63 characters long, start with a letter, contain only letters, numbers, and hyphens, and end with a letter or a number.
  • A full subnetwork path during node pool creation, such as projects/gke-project/regions/us-central1/subnetworks/my-subnet
  • A subnetwork path picked based on the IP utilization during node pool creation and is immutable.
network_tier_config: Option<NetworkTierConfig>

Output only. The network tier configuration for the node pool inherits from the cluster-level configuration and remains immutable throughout the node pool’s lifecycle, including during upgrades.

accelerator_network_profile: String

Immutable. The accelerator network profile for the node pool. For now the only valid value is “auto”. If specified, the network configuration of the nodes in this node pool will be managed by this profile for the supported machine types, zone, etc.

Implementations

Source

impl NodeNetworkConfig

pub fn new() -> Self

Creates a new default instance.

pub fn set_create_pod_range<T: Into<bool>>(self, v: T) -> Self

Sets the value of create_pod_range.

Example
let x = NodeNetworkConfig::new().set_create_pod_range(true);
pub fn set_pod_range<T: Into<String>>(self, v: T) -> Self

Sets the value of pod_range.

Example
let x = NodeNetworkConfig::new().set_pod_range("example");
pub fn set_pod_ipv4_cidr_block<T: Into<String>>(self, v: T) -> Self

Sets the value of pod_ipv4_cidr_block.

Example
let x = NodeNetworkConfig::new().set_pod_ipv4_cidr_block("example");
pub fn set_enable_private_nodes<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of enable_private_nodes.

Example
let x = NodeNetworkConfig::new().set_enable_private_nodes(true);
pub fn set_or_clear_enable_private_nodes<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of enable_private_nodes.

Example
let x = NodeNetworkConfig::new().set_or_clear_enable_private_nodes(Some(false));
let x = NodeNetworkConfig::new().set_or_clear_enable_private_nodes(None::<bool>);
pub fn set_network_performance_config<T>(self, v: T) -> Self

Sets the value of network_performance_config.

Example
use google_cloud_container_v1::model::node_network_config::NetworkPerformanceConfig;
let x = NodeNetworkConfig::new().set_network_performance_config(NetworkPerformanceConfig::default()/* use setters */);
pub fn set_or_clear_network_performance_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of network_performance_config.

Example
use google_cloud_container_v1::model::node_network_config::NetworkPerformanceConfig;
let x = NodeNetworkConfig::new().set_or_clear_network_performance_config(Some(NetworkPerformanceConfig::default()/* use setters */));
let x = NodeNetworkConfig::new().set_or_clear_network_performance_config(None::<NetworkPerformanceConfig>);
pub fn set_pod_cidr_overprovision_config<T>(self, v: T) -> Self

Sets the value of pod_cidr_overprovision_config.

Example
use google_cloud_container_v1::model::PodCIDROverprovisionConfig;
let x = NodeNetworkConfig::new().set_pod_cidr_overprovision_config(PodCIDROverprovisionConfig::default()/* use setters */);
pub fn set_or_clear_pod_cidr_overprovision_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of pod_cidr_overprovision_config.

Example
use google_cloud_container_v1::model::PodCIDROverprovisionConfig;
let x = NodeNetworkConfig::new().set_or_clear_pod_cidr_overprovision_config(Some(PodCIDROverprovisionConfig::default()/* use setters */));
let x = NodeNetworkConfig::new().set_or_clear_pod_cidr_overprovision_config(None::<PodCIDROverprovisionConfig>);
pub fn set_additional_node_network_configs<T, V>(self, v: T) -> Self

Sets the value of additional_node_network_configs.

Example
use google_cloud_container_v1::model::AdditionalNodeNetworkConfig;
let x = NodeNetworkConfig::new()
    .set_additional_node_network_configs([
        AdditionalNodeNetworkConfig::default()/* use setters */,
        AdditionalNodeNetworkConfig::default()/* use (different) setters */,
    ]);
pub fn set_additional_pod_network_configs<T, V>(self, v: T) -> Self

Sets the value of additional_pod_network_configs.

Example
use google_cloud_container_v1::model::AdditionalPodNetworkConfig;
let x = NodeNetworkConfig::new()
    .set_additional_pod_network_configs([
        AdditionalPodNetworkConfig::default()/* use setters */,
        AdditionalPodNetworkConfig::default()/* use (different) setters */,
    ]);
pub fn set_pod_ipv4_range_utilization<T: Into<f64>>(self, v: T) -> Self

Sets the value of pod_ipv4_range_utilization.

Example
let x = NodeNetworkConfig::new().set_pod_ipv4_range_utilization(42.0);
pub fn set_subnetwork<T: Into<String>>(self, v: T) -> Self

Sets the value of subnetwork.

Example
let x = NodeNetworkConfig::new().set_subnetwork("example");
pub fn set_network_tier_config<T>(self, v: T) -> Self

Sets the value of network_tier_config.

Example
use google_cloud_container_v1::model::NetworkTierConfig;
let x = NodeNetworkConfig::new().set_network_tier_config(NetworkTierConfig::default()/* use setters */);
pub fn set_or_clear_network_tier_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of network_tier_config.

Example
use google_cloud_container_v1::model::NetworkTierConfig;
let x = NodeNetworkConfig::new().set_or_clear_network_tier_config(Some(NetworkTierConfig::default()/* use setters */));
let x = NodeNetworkConfig::new().set_or_clear_network_tier_config(None::<NetworkTierConfig>);
pub fn set_accelerator_network_profile<T: Into<String>>(self, v: T) -> Self

Sets the value of accelerator_network_profile.

Example
let x = NodeNetworkConfig::new().set_accelerator_network_profile("example");