RecurringMaintenanceWindow

Struct RecurringMaintenanceWindow 

#[non_exhaustive]
pub struct RecurringMaintenanceWindow { pub delay_until: Option<Date>, pub window_start_time: Option<TimeOfDay>, pub window_duration: Option<Duration>, pub recurrence: String, /* private fields */ }
Represents an arbitrary window of time that recurs. Will replace RecurringTimeWindow.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
delay_until: Option<Date>

Optional. Specifies the date before which will not be scheduled. Depending on the recurrence, this may be the date the first window appears. Days are measured in the UTC timezone. This setting must be used when INTERVAL>1 or FREQ=WEEKLY/MONTHLY and no BYDAY specified.

window_start_time: Option<TimeOfDay>

Required. Start time of the window on days that it is scheduled, assuming UTC timezone.

window_duration: Option<Duration>

Required. Duration of the window.

recurrence: String

Required. An RRULE (https://tools.ietf.org/html/rfc5545#section-3.8.5.3) for how this window recurs.

For example, to have something repeat every weekday, you’d use: FREQ=WEEKLY;BYDAY=MO,TU,WE,TH,FR

To repeat some window daily (equivalent to the DailyMaintenanceWindow): FREQ=DAILY

For the first weekend of every month: FREQ=MONTHLY;BYSETPOS=1;BYDAY=SA,SU

The FREQ values of HOURLY, MINUTELY, and SECONDLY are not supported.

Implementations

Source

impl RecurringMaintenanceWindow

pub fn new() -> Self

Creates a new default instance.

pub fn set_delay_until<T>(self, v: T) -> Self
where T: Into<Date>,

Sets the value of delay_until.

Example
use google_cloud_type::model::Date;
let x = RecurringMaintenanceWindow::new().set_delay_until(Date::default()/* use setters */);
pub fn set_or_clear_delay_until<T>(self, v: Option<T>) -> Self
where T: Into<Date>,

Sets or clears the value of delay_until.

Example
use google_cloud_type::model::Date;
let x = RecurringMaintenanceWindow::new().set_or_clear_delay_until(Some(Date::default()/* use setters */));
let x = RecurringMaintenanceWindow::new().set_or_clear_delay_until(None::<Date>);
pub fn set_window_start_time<T>(self, v: T) -> Self
where T: Into<TimeOfDay>,

Sets the value of window_start_time.

Example
use google_cloud_type::model::TimeOfDay;
let x = RecurringMaintenanceWindow::new().set_window_start_time(TimeOfDay::default()/* use setters */);
pub fn set_or_clear_window_start_time<T>(self, v: Option<T>) -> Self
where T: Into<TimeOfDay>,

Sets or clears the value of window_start_time.

Example
use google_cloud_type::model::TimeOfDay;
let x = RecurringMaintenanceWindow::new().set_or_clear_window_start_time(Some(TimeOfDay::default()/* use setters */));
let x = RecurringMaintenanceWindow::new().set_or_clear_window_start_time(None::<TimeOfDay>);
pub fn set_window_duration<T>(self, v: T) -> Self
where T: Into<Duration>,

Sets the value of window_duration.

Example
use wkt::Duration;
let x = RecurringMaintenanceWindow::new().set_window_duration(Duration::default()/* use setters */);
pub fn set_or_clear_window_duration<T>(self, v: Option<T>) -> Self
where T: Into<Duration>,

Sets or clears the value of window_duration.

Example
use wkt::Duration;
let x = RecurringMaintenanceWindow::new().set_or_clear_window_duration(Some(Duration::default()/* use setters */));
let x = RecurringMaintenanceWindow::new().set_or_clear_window_duration(None::<Duration>);
pub fn set_recurrence<T: Into<String>>(self, v: T) -> Self

Sets the value of recurrence.

Example
let x = RecurringMaintenanceWindow::new().set_recurrence("example");