#[non_exhaustive]pub struct SlurmOperatorConfig {
pub enabled: bool,
/* private fields */
}Expand description
Configuration for the Slurm Operator.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolWhen enabled, it runs a Slurm Operator that manages the set of compute pods for Slurm Cluster.
Implementations