#[non_exhaustive]pub struct TaintConfig {
pub architecture_taint_behavior: Option<ArchitectureTaintBehavior>,
/* private fields */
}Expand description
TaintConfig contains the configuration for the taints of the node pool.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.architecture_taint_behavior: Option<ArchitectureTaintBehavior>Optional. Controls architecture tainting behavior.
Implementations
Sourceimpl TaintConfig
impl TaintConfig
Sourcepub fn set_architecture_taint_behavior<T>(self, v: T) -> Selfwhere
T: Into<ArchitectureTaintBehavior>,
pub fn set_architecture_taint_behavior<T>(self, v: T) -> Selfwhere
T: Into<ArchitectureTaintBehavior>,
Sets the value of architecture_taint_behavior.
Example
ⓘ
use google_cloud_container_v1::model::taint_config::ArchitectureTaintBehavior;
let x0 = TaintConfig::new().set_architecture_taint_behavior(ArchitectureTaintBehavior::None);
let x1 = TaintConfig::new().set_architecture_taint_behavior(ArchitectureTaintBehavior::Arm);Sourcepub fn set_or_clear_architecture_taint_behavior<T>(self, v: Option<T>) -> Selfwhere
T: Into<ArchitectureTaintBehavior>,
pub fn set_or_clear_architecture_taint_behavior<T>(self, v: Option<T>) -> Selfwhere
T: Into<ArchitectureTaintBehavior>,
Sets or clears the value of architecture_taint_behavior.
Example
ⓘ
use google_cloud_container_v1::model::taint_config::ArchitectureTaintBehavior;
let x0 = TaintConfig::new().set_or_clear_architecture_taint_behavior(Some(ArchitectureTaintBehavior::None));
let x1 = TaintConfig::new().set_or_clear_architecture_taint_behavior(Some(ArchitectureTaintBehavior::Arm));
let x_none = TaintConfig::new().set_or_clear_architecture_taint_behavior(None::<ArchitectureTaintBehavior>);Trait Implementations
Sourceimpl Clone for TaintConfig
impl Clone for TaintConfig
Sourcefn clone(&self) -> TaintConfig
fn clone(&self) -> TaintConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaintConfig
impl Debug for TaintConfig
Sourceimpl Default for TaintConfig
impl Default for TaintConfig
Sourcefn default() -> TaintConfig
fn default() -> TaintConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for TaintConfig
impl Message for TaintConfig
Sourceimpl PartialEq for TaintConfig
impl PartialEq for TaintConfig
Sourcefn eq(&self, other: &TaintConfig) -> bool
fn eq(&self, other: &TaintConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TaintConfig