#[non_exhaustive]pub struct UpgradeEvent {
pub resource_type: UpgradeResourceType,
pub operation: String,
pub operation_start_time: Option<Timestamp>,
pub current_version: String,
pub target_version: String,
pub current_emulated_version: String,
pub target_emulated_version: String,
pub resource: String,
/* private fields */
}Expand description
UpgradeEvent is a notification sent to customers by the cluster server when a resource is upgrading.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_type: UpgradeResourceTypeThe resource type that is upgrading.
operation: StringThe operation associated with this upgrade.
operation_start_time: Option<Timestamp>The time when the operation was started.
current_version: StringThe current version before the upgrade.
target_version: StringThe target version for the upgrade.
current_emulated_version: StringOutput only. The current emulated version before the upgrade.
target_emulated_version: StringOutput only. The target emulated version for the upgrade.
resource: StringOptional relative path to the resource. For example in node pool upgrades, the relative path of the node pool.
Implementations
Sourceimpl UpgradeEvent
impl UpgradeEvent
Sourcepub fn set_resource_type<T: Into<UpgradeResourceType>>(self, v: T) -> Self
pub fn set_resource_type<T: Into<UpgradeResourceType>>(self, v: T) -> Self
Sets the value of resource_type.
Example
use google_cloud_container_v1::model::UpgradeResourceType;
let x0 = UpgradeEvent::new().set_resource_type(UpgradeResourceType::Master);
let x1 = UpgradeEvent::new().set_resource_type(UpgradeResourceType::NodePool);Sourcepub fn set_operation<T: Into<String>>(self, v: T) -> Self
pub fn set_operation<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_operation_start_time<T>(self, v: T) -> Self
pub fn set_operation_start_time<T>(self, v: T) -> Self
Sets the value of operation_start_time.
Example
use wkt::Timestamp;
let x = UpgradeEvent::new().set_operation_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_operation_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_operation_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of operation_start_time.
Example
use wkt::Timestamp;
let x = UpgradeEvent::new().set_or_clear_operation_start_time(Some(Timestamp::default()/* use setters */));
let x = UpgradeEvent::new().set_or_clear_operation_start_time(None::<Timestamp>);Sourcepub fn set_current_version<T: Into<String>>(self, v: T) -> Self
pub fn set_current_version<T: Into<String>>(self, v: T) -> Self
Sets the value of current_version.
Example
let x = UpgradeEvent::new().set_current_version("example");Sourcepub fn set_target_version<T: Into<String>>(self, v: T) -> Self
pub fn set_target_version<T: Into<String>>(self, v: T) -> Self
Sets the value of target_version.
Example
let x = UpgradeEvent::new().set_target_version("example");Sourcepub fn set_current_emulated_version<T: Into<String>>(self, v: T) -> Self
pub fn set_current_emulated_version<T: Into<String>>(self, v: T) -> Self
Sets the value of current_emulated_version.
Example
let x = UpgradeEvent::new().set_current_emulated_version("example");Sourcepub fn set_target_emulated_version<T: Into<String>>(self, v: T) -> Self
pub fn set_target_emulated_version<T: Into<String>>(self, v: T) -> Self
Sets the value of target_emulated_version.
Example
let x = UpgradeEvent::new().set_target_emulated_version("example");Trait Implementations
Sourceimpl Clone for UpgradeEvent
impl Clone for UpgradeEvent
Sourcefn clone(&self) -> UpgradeEvent
fn clone(&self) -> UpgradeEvent
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more