#[non_exhaustive]pub struct RecurringMaintenanceWindow {
pub delay_until: Option<Date>,
pub window_start_time: Option<TimeOfDay>,
pub window_duration: Option<Duration>,
pub recurrence: String,
/* private fields */
}Expand description
Represents an arbitrary window of time that recurs. Will replace RecurringTimeWindow.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delay_until: Option<Date>Optional. Specifies the date before which will not be scheduled. Depending on the recurrence, this may be the date the first window appears. Days are measured in the UTC timezone. This setting must be used when INTERVAL>1 or FREQ=WEEKLY/MONTHLY and no BYDAY specified.
window_start_time: Option<TimeOfDay>Required. Start time of the window on days that it is scheduled, assuming UTC timezone.
window_duration: Option<Duration>Required. Duration of the window.
recurrence: StringRequired. An RRULE (https://tools.ietf.org/html/rfc5545#section-3.8.5.3) for how this window recurs.
For example, to have something repeat every weekday, you’d use:
FREQ=WEEKLY;BYDAY=MO,TU,WE,TH,FR
To repeat some window daily (equivalent to the DailyMaintenanceWindow):
FREQ=DAILY
For the first weekend of every month:
FREQ=MONTHLY;BYSETPOS=1;BYDAY=SA,SU
The FREQ values of HOURLY, MINUTELY, and SECONDLY are not supported.
Implementations
Sourceimpl RecurringMaintenanceWindow
impl RecurringMaintenanceWindow
Sourcepub fn set_delay_until<T>(self, v: T) -> Self
pub fn set_delay_until<T>(self, v: T) -> Self
Sets the value of delay_until.
Example
use google_cloud_type::model::Date;
let x = RecurringMaintenanceWindow::new().set_delay_until(Date::default()/* use setters */);Sourcepub fn set_or_clear_delay_until<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_delay_until<T>(self, v: Option<T>) -> Self
Sets or clears the value of delay_until.
Example
use google_cloud_type::model::Date;
let x = RecurringMaintenanceWindow::new().set_or_clear_delay_until(Some(Date::default()/* use setters */));
let x = RecurringMaintenanceWindow::new().set_or_clear_delay_until(None::<Date>);Sourcepub fn set_window_start_time<T>(self, v: T) -> Self
pub fn set_window_start_time<T>(self, v: T) -> Self
Sets the value of window_start_time.
Example
use google_cloud_type::model::TimeOfDay;
let x = RecurringMaintenanceWindow::new().set_window_start_time(TimeOfDay::default()/* use setters */);Sourcepub fn set_or_clear_window_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_window_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of window_start_time.
Example
use google_cloud_type::model::TimeOfDay;
let x = RecurringMaintenanceWindow::new().set_or_clear_window_start_time(Some(TimeOfDay::default()/* use setters */));
let x = RecurringMaintenanceWindow::new().set_or_clear_window_start_time(None::<TimeOfDay>);Sourcepub fn set_window_duration<T>(self, v: T) -> Self
pub fn set_window_duration<T>(self, v: T) -> Self
Sets the value of window_duration.
Example
use wkt::Duration;
let x = RecurringMaintenanceWindow::new().set_window_duration(Duration::default()/* use setters */);Sourcepub fn set_or_clear_window_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_window_duration<T>(self, v: Option<T>) -> Self
Sets or clears the value of window_duration.
Example
use wkt::Duration;
let x = RecurringMaintenanceWindow::new().set_or_clear_window_duration(Some(Duration::default()/* use setters */));
let x = RecurringMaintenanceWindow::new().set_or_clear_window_duration(None::<Duration>);Sourcepub fn set_recurrence<T: Into<String>>(self, v: T) -> Self
pub fn set_recurrence<T: Into<String>>(self, v: T) -> Self
Sets the value of recurrence.
Example
let x = RecurringMaintenanceWindow::new().set_recurrence("example");Trait Implementations
Sourceimpl Clone for RecurringMaintenanceWindow
impl Clone for RecurringMaintenanceWindow
Sourcefn clone(&self) -> RecurringMaintenanceWindow
fn clone(&self) -> RecurringMaintenanceWindow
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RecurringMaintenanceWindow
impl Debug for RecurringMaintenanceWindow
Sourceimpl Default for RecurringMaintenanceWindow
impl Default for RecurringMaintenanceWindow
Sourcefn default() -> RecurringMaintenanceWindow
fn default() -> RecurringMaintenanceWindow
Sourceimpl Message for RecurringMaintenanceWindow
impl Message for RecurringMaintenanceWindow
Sourceimpl PartialEq for RecurringMaintenanceWindow
impl PartialEq for RecurringMaintenanceWindow
Sourcefn eq(&self, other: &RecurringMaintenanceWindow) -> bool
fn eq(&self, other: &RecurringMaintenanceWindow) -> bool
self and other values to be equal, and is used by ==.